// Deps
var _       = require('lodash');
var express = require('express');
var path    = require('path');

// Routes
var mainRouter = express.Router();

// Globals
var db;
var adminPath;

/**
 * Creates renders and returns html
 *
 * @param {object} res
 * @param {string} templateFilename
 * @param {object} params
 */
var render = function (response, templateFilename, params) {
  "use strict";

  params = params || {};
  params._ = _;
  params.adminPath = adminPath;
  params.models = Object.keys(db.models);

  return response.render(path.join(__dirname, './views/' + templateFilename + '.html'), params);
};

/**
 * Homepage
 */
mainRouter.route('/').get(function (req, res) {
  return render(res, 'home');
});




mainRouter.use('/:modelname/:action', function (req, res) {
  if (!_.has(db.models, req.params.modelname)) {
    return res.end('model yook')
  }

  res.end('model=' + req.params.modelname + ' action=' + req.params.action)
})




/**
 * List view
 */
mainRouter.use('/:modelname', function(req, res) {
  "use strict";

  var modelname = req.params.modelname;
  var model = _.get(db.models, modelname);

  if (!model) {
    return res.end('model yook')
  }

  model.describe().then(function(schema) {
    model.findAll({}).then(function (results) {
      return render(res, 'list', {
        schema: schema,
        results: results,
        modelname: modelname
      });
    });
  });
});

/**
 * Exports
 */
module.exports = function (app, dbData, path) {
  path = path || '/admin';
  db = dbData;
  adminPath = path;

  app.use(adminPath, mainRouter);
};